# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 10
# Methods Covered : 10
# Examples Total  : 10
# Examples Tested : 10
# Coverage %      : 100
# ----------------------

#  route_filters: 6/6
#  route_filter_rules:  4/4
#  service_tags: 1/1
#  bgp_service_communities: 1/1

import unittest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
import pytest

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        ROUTE_FILTER_NAME = "myRouteFilter"
        RULE_NAME = "myRule"
        LOCATION = AZURE_LOCATION

        # /RouteFilters/put/RouteFilterCreate[put]
        BODY = {
            "location": AZURE_LOCATION,
            "tags": {"key1": "value1"},
            "rules": [
                # {
                #   "name": "ruleName",
                #   "properties": {
                #     "access": "Allow",
                #     "route_filter_rule_type": "Community",
                #     "communities": [
                #       "12076:5030",
                #       "12076:5040"
                #     ]
                #   }
                # }
            ],
        }
        result = self.mgmt_client.route_filters.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME, route_filter_parameters=BODY
        )
        result = result.result()

        # /ServiceTags/get/Get list of service tags[get]
        result = self.mgmt_client.service_tags.list(location=LOCATION)

        # /BgpServiceCommunities/get/ServiceCommunityList[get]
        result = self.mgmt_client.bgp_service_communities.list()

        # /RouteFilterRules/put/RouteFilterRuleCreate[put]
        BODY = {
            "access": "Allow",
            "route_filter_rule_type": "Community",
            "communities": [
                # "12076:5030",
                "12076:51004"
                # "12076:5040"
            ],
        }
        result = self.mgmt_client.route_filter_rules.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP,
            route_filter_name=ROUTE_FILTER_NAME,
            rule_name=RULE_NAME,
            route_filter_rule_parameters=BODY,
        )
        result = result.result()

        # /RouteFilterRules/get/RouteFilterRuleGet[get]
        result = self.mgmt_client.route_filter_rules.get(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME, rule_name=RULE_NAME
        )

        # /RouteFilterRules/get/RouteFilterRuleListByRouteFilter[get]
        result = self.mgmt_client.route_filter_rules.list_by_route_filter(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME
        )

        # /RouteFilters/get/RouteFilterGet[get]
        result = self.mgmt_client.route_filters.get(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME
        )

        # /RouteFilters/get/RouteFilterListByResourceGroup[get]
        result = self.mgmt_client.route_filters.list_by_resource_group(resource_group_name=RESOURCE_GROUP)

        # /RouteFilters/get/RouteFilterList[get]
        result = self.mgmt_client.route_filters.list()

        # /RouteFilters/patch/Update route filter tags[patch]
        BODY = {"tags": {"key1": "value1"}}
        result = self.mgmt_client.route_filters.update_tags(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME, parameters=BODY
        )

        # /RouteFilterRules/delete/RouteFilterRuleDelete[delete]
        result = self.mgmt_client.route_filter_rules.begin_delete(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME, rule_name=RULE_NAME
        )
        result = result.result()

        # /RouteFilters/delete/RouteFilterDelete[delete]
        result = self.mgmt_client.route_filters.begin_delete(
            resource_group_name=RESOURCE_GROUP, route_filter_name=ROUTE_FILTER_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 63
# Methods Covered : 63
# Examples Total  : 76
# Examples Tested : 76
# Coverage %      : 100
# ----------------------

# covered ops:
#   virtual_networks: 8/8
#   virtual_network_taps: 0/6  TODO: SubscriptionNotRegisteredForFeature.
#   virtual_network_peerings: 4/4
#   virtual_network_gateways: 12/22  TODO: others need vpnclient
#   virtual_network_gateway_connections: 8/10  TODO: Start packet capture return 500
#   local_network_gateways: 5/5
#   subnets: 4/6  TODO: SubscriptionNotRegisteredForFeature in Prepare/Unprepare Network Policies
#   service_association_links: 1/1
#   resource_navigation_links: 1/1
#   virtual_routers: 0/5  #TODO:PutVirtualRouter feature not enabled
#   virtual_router_peerings: 0/4

import unittest
import time
import pytest

from azure.core.exceptions import HttpResponseError
import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    def create_network_interface(self, group_name, location, nic_name, subnet_id, ipconfig):

        async_nic_creation = self.mgmt_client.network_interfaces.begin_create_or_update(
            group_name,
            nic_name,
            {"location": location, "ip_configurations": [{"name": ipconfig, "subnet": {"id": subnet_id}}]},
        )
        nic_info = async_nic_creation.result()

        return nic_info

    def delete_network_interface(self, group_name, nic_name):
        result = self.mgmt_client.network_interfaces.begin_delete(group_name, nic_name)
        return result.result()

    def create_public_ip_addresses(self, group_name, location, public_ip_name):
        # Create PublicIP
        BODY = {"location": location, "public_ip_allocation_method": "Dynamic", "idle_timeout_in_minutes": 4}
        result = self.mgmt_client.public_ip_addresses.begin_create_or_update(group_name, public_ip_name, BODY)
        return result.result()

    @pytest.mark.skip(reason="fix later")
    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SERVICE_NAME = "myapimrndxyz"
        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name

        VIRTUAL_NETWORK_NAME = "virtualnetworkname"
        REMOTE_VIRTUAL_NETWORK_NAME = "rmvirtualnetworkname"
        VIRTUAL_NETWORK_TAP_NAME = "virtualnetworktapname"
        NETWORK_INTERFACE_NAME = "networkinterfacename"
        VIRTUAL_NETWORK_PEERING_NAME = "virtualnetworkpeeringname"
        PUBLIC_IP_ADDRESS_NAME = "publicipname"
        VIRTUAL_NETWORK_GATEWAY_NAME = "virtualnetworkgatewayname"
        LOCAL_NETWORK_GATEWAY_NAME = "localnetworkgatewayname"
        IP_CONFIGURATION_NAME = "ipconfig"
        CONNECTION_NAME = "connectionname"
        SUBNET_NAME = "subnetname"
        GATEWAY_SUBNET_NAME = "GatewaySubnet"
        VIRTUAL_ROUTER_NAME = "virtualroute"

        self.create_public_ip_addresses(resource_group.name, AZURE_LOCATION, PUBLIC_IP_ADDRESS_NAME)

        # Create virtual network[put]
        BODY = {"address_space": {"address_prefixes": ["10.0.0.0/16"]}, "location": "eastus"}
        result = self.mgmt_client.virtual_networks.begin_create_or_update(
            resource_group.name, VIRTUAL_NETWORK_NAME, BODY
        )
        result = result.result()

        # Create remote virtual network[put]
        BODY = {"address_space": {"address_prefixes": ["10.2.0.0/16"]}, "location": "eastus"}
        result = self.mgmt_client.virtual_networks.begin_create_or_update(
            resource_group.name, REMOTE_VIRTUAL_NETWORK_NAME, BODY
        )
        result = result.result()

        # Create subnet[put]
        BODY = {"address_prefix": "10.0.0.0/24"}
        result = self.mgmt_client.subnets.begin_create_or_update(
            resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY
        )
        subnet = result.result()

        self.create_network_interface(
            resource_group.name, AZURE_LOCATION, NETWORK_INTERFACE_NAME, subnet.id, IP_CONFIGURATION_NAME
        )

        # Create gateway subnet[put]
        BODY = {"address_prefix": "10.0.1.0/24"}
        result = self.mgmt_client.subnets.begin_create_or_update(
            resource_group.name, VIRTUAL_NETWORK_NAME, GATEWAY_SUBNET_NAME, BODY
        )
        subnet = result.result()

        # TODO: NOT ALLOW
        # Create Virtual Network Tap[put]
        # BODY = {
        #   "destination_network_interface_ip_configuration": {
        #     "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/networkInterfaces/" + NETWORK_INTERFACE_NAME + "/ipConfigurations/" + IP_CONFIGURATION_NAME + ""
        #   },
        #   "location": "eastus"
        # }
        # result = self.mgmt_client.virtual_network_taps.begin_create_or_update(resource_group.name, VIRTUAL_NETWORK_TAP_NAME, BODY)
        # result = result.result()

        # CreateLocalNetworkGateway[put]
        BODY = {
            "local_network_address_space": {"address_prefixes": ["10.1.0.0/16"]},
            "gateway_ip_address": "11.12.13.14",
            "location": "eastus",
        }
        result = self.mgmt_client.local_network_gateways.begin_create_or_update(
            resource_group.name, LOCAL_NETWORK_GATEWAY_NAME, BODY
        )
        result = result.result()

        # UpdateVirtualNetworkGateway[put]
        BODY = {
            "ip_configurations": [
                {
                    "private_ip_allocation_method": "Dynamic",
                    "subnet": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/virtualNetworks/"
                        + VIRTUAL_NETWORK_NAME
                        + "/subnets/"
                        + GATEWAY_SUBNET_NAME
                        + ""
                    },
                    "public_ip_address": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/publicIPAddresses/"
                        + PUBLIC_IP_ADDRESS_NAME
                        + ""
                    },
                    "name": IP_CONFIGURATION_NAME,
                }
            ],
            "gateway_type": "Vpn",
            "vpn_type": "RouteBased",
            "enable_bgp": False,
            "active_active": False,
            "enable_dns_forwarding": False,
            "sku": {"name": "VpnGw1", "tier": "VpnGw1"},
            "bgp_settings": {"asn": "65515", "bgp_peering_address": "10.0.1.30", "peer_weight": "0"},
            "custom_routes": {"address_prefixes": ["101.168.0.6/32"]},
            "location": "eastus",
        }
        result = self.mgmt_client.virtual_network_gateways.begin_create_or_update(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY
        )
        result = result.result()

        # TODO:PutVirtualRouter feature not enabled
        # Create VirtualRouter[put]
        # BODY = {
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "location": "West US",
        #   "hosted_gateway": {
        #     "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworkGateways/" + VIRTUAL_NETWORK_GATEWAY_NAME + ""
        #   }
        # }
        # result = self.mgmt_client.virtual_routers.begin_create_or_update(resource_group.name, VIRTUAL_ROUTER_NAME, BODY)
        # result = result.result()

        # # Create Virtual Router Peering[put]
        # BODY = {
        #   "properties": {
        #     "peer_ip": "192.168.1.5",
        #     "peer_asn": "20000"
        #   }
        # }
        # result = self.mgmt_client.virtual_router_peerings.create_or_update(resource_group.name, VIRTUAL_ROUTER_NAME, PEERING_NAME, BODY)
        # result = result.result()

        """
        # Create subnet with a delegation[put]
        BODY = {
          "properties": {
            "address_prefix": "10.0.0.0/16"
          }
        }
        result = self.mgmt_client.subnets.create_or_update(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY)
        result = result.result()

        # Create subnet with service endpoints[put]
        BODY = {
          "properties": {
            "address_prefix": "10.0.0.0/16",
            "service_endpoints": [
              {
                "service": "Microsoft.Storage"
              }
            ]
          }
        }
        result = self.mgmt_client.subnets.create_or_update(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY)
        result = result.result()
        """

        # Create peering[put]
        BODY = {
            "allow_virtual_network_access": True,
            "allow_forwarded_traffic": True,
            "allow_gateway_transit": False,
            "use_remote_gateways": False,
            "remote_virtual_network": {
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/virtualNetworks/"
                + REMOTE_VIRTUAL_NETWORK_NAME
                + ""
            },
        }
        result = self.mgmt_client.virtual_network_peerings.begin_create_or_update(
            resource_group.name, VIRTUAL_NETWORK_NAME, VIRTUAL_NETWORK_PEERING_NAME, BODY
        )
        result = result.result()

        # CreateVirtualNetworkGatewayConnection_S2S[put]
        BODY = {
            "virtual_network_gateway1": {
                "ip_configurations": [
                    {
                        "private_ip_allocation_method": "Dynamic",
                        "subnet": {
                            "id": "/subscriptions/"
                            + SUBSCRIPTION_ID
                            + "/resourceGroups/"
                            + RESOURCE_GROUP
                            + "/providers/Microsoft.Network/virtualNetworks/"
                            + VIRTUAL_NETWORK_NAME
                            + "/subnets/"
                            + GATEWAY_SUBNET_NAME
                            + ""
                        },
                        "public_ip_address": {
                            "id": "/subscriptions/"
                            + SUBSCRIPTION_ID
                            + "/resourceGroups/"
                            + RESOURCE_GROUP
                            + "/providers/Microsoft.Network/publicIPAddresses/"
                            + PUBLIC_IP_ADDRESS_NAME
                            + ""
                        },
                        "name": IP_CONFIGURATION_NAME,
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/virtualNetworkGateways/"
                        + VIRTUAL_NETWORK_GATEWAY_NAME
                        + "/ipConfigurations/"
                        + IP_CONFIGURATION_NAME
                        + "",
                    }
                ],
                "gateway_type": "Vpn",
                "vpn_type": "RouteBased",
                "enable_bgp": False,
                "active_active": False,
                "sku": {"name": "VpnGw1", "tier": "VpnGw1"},
                "bgp_settings": {"asn": "65514", "bgp_peering_address": "10.0.2.30", "peer_weight": "0"},
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/virtualNetworkGateways/"
                + VIRTUAL_NETWORK_GATEWAY_NAME
                + "",
                "location": "eastus",
            },
            "local_network_gateway2": {
                "local_network_address_space": {"address_prefixes": ["10.1.0.0/16"]},
                "gateway_ip_address": "10.1.0.1",
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/localNetworkGateways/"
                + LOCAL_NETWORK_GATEWAY_NAME
                + "",
                "location": "eastus",
            },
            "connection_type": "IPsec",
            "connection_protocol": "IKEv2",
            "routing_weight": "0",
            "shared_key": "Abc123",
            "enable_bgp": False,
            "use_policy_based_traffic_selectors": False,
            "ipsec_policies": [],
            "traffic_selector_policies": [],
            "location": "eastus",
        }
        result = self.mgmt_client.virtual_network_gateway_connections.begin_create_or_update(
            resource_group.name, CONNECTION_NAME, BODY
        )
        result = result.result()

        # SetVirtualNetworkGatewayConnectionSharedKey[put]
        BODY = {"value": "AzureAbc123"}
        result = self.mgmt_client.virtual_network_gateway_connections.begin_set_shared_key(
            resource_group.name, CONNECTION_NAME, BODY
        )
        result = result.result()

        # Get VirtualRouter[get]
        # result = self.mgmt_client.virtual_routers.get(resource_group.name, VIRTUAL_ROUTER_NAME)

        # # Get Virtual Router Peering[get]
        # result = self.mgmt_client.virtual_router_peerings.get(resource_group.name, VIRTUAL_ROUTER_NAME, PEERING_NAME)

        # Get peering[get]
        result = self.mgmt_client.virtual_network_peerings.get(
            resource_group.name, VIRTUAL_NETWORK_NAME, VIRTUAL_NETWORK_PEERING_NAME
        )

        # Get Service Association Links[get]
        result = self.mgmt_client.service_association_links.list(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)

        # Get Resource Navigation Links[get]
        result = self.mgmt_client.resource_navigation_links.list(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)

        # Check IP address availability[get]
        IP_ADDRESS = "10.0.1.4"
        result = self.mgmt_client.virtual_networks.check_ip_address_availability(
            resource_group.name, VIRTUAL_NETWORK_NAME, IP_ADDRESS
        )

        # VirtualNetworkGatewaysListConnections[get]
        result = self.mgmt_client.virtual_network_gateways.list_connections(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME
        )

        # Get subnet[get]
        result = self.mgmt_client.subnets.get(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)

        """
        # Get subnet with a delegation[get]
        result = self.mgmt_client.subnets.get(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        """

        # List peerings[get]
        result = self.mgmt_client.virtual_network_peerings.list(resource_group.name, VIRTUAL_NETWORK_NAME)

        # List all Virtual Router for a given resource group[get]
        # result = self.mgmt_client.virtual_routers.list_by_resource_group(resource_group.name)

        # # List all Virtual Router Peerings for a given Virtual Router[get]
        # result = self.mgmt_client.virtual_router_peerings.list(resource_group.name, VIRTUAL_ROUTER_NAME)

        # GetVirtualNetworkGateway[get]
        result = self.mgmt_client.virtual_network_gateways.get(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)

        # GetLocalNetworkGateway[get]
        result = self.mgmt_client.local_network_gateways.get(resource_group.name, LOCAL_NETWORK_GATEWAY_NAME)

        # List subnets[get]
        result = self.mgmt_client.subnets.list(resource_group.name, VIRTUAL_NETWORK_NAME)

        # TODO: NOT ALLOW
        # # Get Virtual Network Tap[get]
        # result = self.mgmt_client.virtual_network_taps.get(resource_group.name, VIRTUAL_NETWORK_TAP_NAME)

        # VnetGetUsage[get]
        result = self.mgmt_client.virtual_networks.list_usage(resource_group.name, VIRTUAL_NETWORK_NAME)

        # GetVirtualNetworkGatewayConnectionSharedKey[get]
        result = self.mgmt_client.virtual_network_gateway_connections.get_shared_key(
            resource_group.name, CONNECTION_NAME
        )

        # Get virtual network[get]
        result = self.mgmt_client.virtual_networks.get(resource_group.name, VIRTUAL_NETWORK_NAME)

        """
        # Get virtual network with a delegated subnet[get]
        result = self.mgmt_client.virtual_networks.get(resource_group.name, VIRTUAL_NETWORK_NAME)

        # Get virtual network with service association links[get]
        result = self.mgmt_client.virtual_networks.get(resource_group.name, VIRTUAL_NETWORK_NAME)
        """

        # GetVirtualNetworkGatewayConnection[get]
        result = self.mgmt_client.virtual_network_gateway_connections.get(resource_group.name, CONNECTION_NAME)

        # ListVirtualNetworkGatewaysinResourceGroup[get]
        result = self.mgmt_client.virtual_network_gateways.list(resource_group.name)

        # ListLocalNetworkGateways[get]
        result = self.mgmt_client.local_network_gateways.list(resource_group.name)

        # TODO: NOT ALLOW
        # List virtual network taps in resource group[get]
        # result = self.mgmt_client.virtual_network_taps.list_by_resource_group(resource_group.name)

        # List virtual networks in resource group[get]
        result = self.mgmt_client.virtual_networks.list(resource_group.name)

        # ListVirtualNetworkGatewayConnectionsinResourceGroup[get]
        result = self.mgmt_client.virtual_network_gateway_connections.list(resource_group.name)

        # TODO: NOT ALLOW
        # List all virtual network taps[get]
        # result = self.mgmt_client.virtual_network_taps.list_all()

        # List all virtual networks[get]
        result = self.mgmt_client.virtual_networks.list_all()

        # List all Virtual Routers for a given subscription[get]
        # result = self.mgmt_client.virtual_routers.list()

        # TODO: NEED VPN CLIENT
        # Disconnect VpnConnections from Virtual Network Gateway[post]
        # BODY = {
        #   "vpn_connection_ids": [
        #     # "vpnconnId1",
        #     # "vpnconnId2"
        #   ]
        # }
        # result = self.mgmt_client.virtual_network_gateways.begin_disconnect_virtual_network_gateway_vpn_connections(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY["vpn_connection_ids"])
        # result = result.result()

        # TODO: SubscriptionNotRegisteredForFeature
        # Prepare Network Policies[post]
        # BODY = {
        #   "service_name": "Microsoft.Sql/managedInstances"
        # }
        # result = self.mgmt_client.subnets.begin_prepare_network_policies(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY["service_name"])
        # result = result.result()

        # TODO: SubscriptionNotRegisteredForFeature
        # Unprepare Network Policies[post]
        # BODY = {
        #   "service_name": "Microsoft.Sql/managedInstances"
        # }
        # result = self.mgmt_client.subnets.begin_unprepare_network_policies(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY["service_name"])
        # result = result.result()

        """ TODO: NEED VPN CLIENT
        # GetVirtualNetworkGatewayVpnclientConnectionHealth[post]
        # result = self.mgmt_client.virtual_network_gateways.begin_get_vpnclient_connection_health(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        # result = result.result()

        # Get VirtualNetworkGateway VpnClientIpsecParameters[post]
        # result = self.mgmt_client.virtual_network_gateways.begin_get_vpnclient_ipsec_parameters(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        # result = result.result()

        # Set VirtualNetworkGateway VpnClientIpsecParameters[post]
        BODY = {
          "sa_life_time_seconds": "86473",
          "sa_data_size_kilobytes": "429497",
          "ipsec_encryption": "AES256",
          "ipsec_integrity": "SHA256",
          "ike_encryption": "AES256",
          "ike_integrity": "SHA384",
          "dh_group": "DHGroup2",
          "pfs_group": "PFS2"
        }
        result = self.mgmt_client.virtual_network_gateways.begin_set_vpnclient_ipsec_parameters(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY)
        result = result.result()

        # GenerateVPNClientPackage[post]
        BODY = {}
        result = self.mgmt_client.virtual_network_gateways.begin_generatevpnclientpackage(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY)
        result = result.result()

        # ResetVpnClientSharedKey[post]
        result = self.mgmt_client.virtual_network_gateways.begin_reset_vpn_client_shared_key(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        result = result.result()

        # GetVirtualNetworkGatewayVPNProfilePackageURL[post]
        result = self.mgmt_client.virtual_network_gateways.begin_get_vpn_profile_package_url(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        result = result.result()

        # ListVirtualNetworkGatewaySupportedVPNDevices[post]
        result = self.mgmt_client.virtual_network_gateways.begin_supported_vpn_devices(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        """

        # GetVirtualNetworkGatewayAdvertisedRoutes[post]
        # PEER = "test"
        PEER = "10.0.0.2"
        result = self.mgmt_client.virtual_network_gateways.begin_get_advertised_routes(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, PEER
        )
        result = result.result()

        # TODO: NEED VPN CLIENT
        # GenerateVirtualNetworkGatewayVPNProfile[post]
        # BODY = {}
        # result = self.mgmt_client.virtual_network_gateways.begin_generate_vpn_profile(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY)
        # result = result.result()

        # Start packet capture on virtual network gateway with filter[post]
        # BODY = {
        #   "filter_data": "{'TracingFlags': 11,'MaxPacketBufferSize': 120,'MaxFileSize': 200,'Filters': [{'SourceSubnets': ['20.1.1.0/24'],'DestinationSubnets': ['10.1.1.0/24'],'SourcePort': [500],'DestinationPort': [4500],'Protocol': 6,'TcpFlags': 16,'CaptureSingleDirectionTrafficOnly': true}]}"
        # }
        # result = self.mgmt_client.virtual_network_gateways.begin_start_packet_capture(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY["filter_data"])
        # result = result.result()

        # TODO: need fix sas_url later
        # Start packet capture on virtual network gateway without filter[post]
        # result = self.mgmt_client.virtual_network_gateways.begin_start_packet_capture(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        # result = result.result()

        # Stop packet capture on virtual network gateway[post]
        # BODY = {
        #   "sas_url": "fakeuri"
        # }
        # result = self.mgmt_client.virtual_network_gateways.begin_stop_packet_capture(resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME)
        # result = result.result()

        # GetVirtualNetworkGatewayBGPPeerStatus[post]
        result = self.mgmt_client.virtual_network_gateways.begin_get_bgp_peer_status(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME
        )
        result = result.result()

        # GetVirtualNetworkGatewayLearnedRoutes[post]
        result = self.mgmt_client.virtual_network_gateways.begin_get_learned_routes(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME
        )
        result = result.result()

        # ResetVirtualNetworkGatewayConnectionSharedKey[post]
        BODY = {"key_length": "128"}
        result = self.mgmt_client.virtual_network_gateway_connections.begin_reset_shared_key(
            resource_group.name, CONNECTION_NAME, BODY
        )
        result = result.result()

        # ResetVirtualNetworkGateway[post]
        result = self.mgmt_client.virtual_network_gateways.begin_reset(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME
        )
        result = result.result()

        # TODO: NEED VPN CLIENT
        # GetVPNDeviceConfigurationScript[post]
        # BODY = {
        #   "vendor": "Cisco",
        #   "device_family": "ISR",
        #   "firmware_version": "IOS 15.1 (Preview)"
        # }
        # result = self.mgmt_client.virtual_network_gateways.vpn_device_configuration_script(resource_group.name, CONNECTION_NAME, BODY)

        # UpdateVirtualNetworkGatewayTags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.virtual_network_gateways.begin_update_tags(
            resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME, BODY
        )
        result = result.result()

        # UpdateLocalNetworkGatewayTags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.local_network_gateways.update_tags(
            resource_group.name, LOCAL_NETWORK_GATEWAY_NAME, BODY
        )

        # TODO:(InternalServerError) An error occurred.
        # Start packet capture on virtual network gateway connection without filter[post]
        # result = self.mgmt_client.virtual_network_gateway_connections.begin_start_packet_capture(resource_group.name, CONNECTION_NAME)
        # result = result.result()

        # Start packet capture on virtual network gateway connection with filter[post]
        # BODY = {
        #   "filter_data": "{'TracingFlags': 11,'MaxPacketBufferSize': 120,'MaxFileSize': 200,'Filters': [{'SourceSubnets': ['20.1.1.0/24'],'DestinationSubnets': ['10.1.1.0/24'],'SourcePort': [500],'DestinationPort': [4500],'Protocol': 6,'TcpFlags': 16,'CaptureSingleDirectionTrafficOnly': true}]}"
        # }
        # result = self.mgmt_client.virtual_network_gateway_connections.begin_start_packet_capture(resource_group.name, CONNECTION_NAME, BODY["filter_data"])
        # result = result.result()

        # Stop packet capture on virtual network gateway connection[post]
        # BODY = {
        #   "sas_url": "fakeuri"
        # }
        # result = self.mgmt_client.virtual_network_gateway_connections.begin_stop_packet_capture(resource_group.name, CONNECTION_NAME)
        # result = result.result()

        # TODO: NOT ALLOW
        # Update virtual network tap tags[patch]
        # BODY = {
        #   "tags": {
        #     "tag1": "value1",
        #     "tag2": "value2"
        #   }
        # }
        # result = self.mgmt_client.virtual_network_taps.update_tags(resource_group.name, VIRTUAL_NETWORK_TAP_NAME, BODY["tags"])

        # Update virtual network tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.virtual_networks.update_tags(resource_group.name, VIRTUAL_NETWORK_NAME, BODY)

        # UpdateVirtualNetworkGatewayConnectionTags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.virtual_network_gateway_connections.begin_update_tags(
            resource_group.name, CONNECTION_NAME, BODY["tags"]
        )
        result = result.result()

        # DeleteVirtualNetworkGatewayConnection[delete]
        result = self.mgmt_client.virtual_network_gateway_connections.begin_delete(resource_group.name, CONNECTION_NAME)
        result = result.result()

        # Delete peering[delete]
        result = self.mgmt_client.virtual_network_peerings.begin_delete(
            resource_group.name, VIRTUAL_NETWORK_NAME, VIRTUAL_NETWORK_PEERING_NAME
        )
        result = result.result()

        # # Delete VirtualRouterPeering[delete]
        # result = self.mgmt_client.virtual_router_peerings.delete(resource_group.name, VIRTUAL_ROUTER_NAME, PEERING_NAME)
        # result = result.result()

        # Delete VirtualRouter[delete]
        # result = self.mgmt_client.virtual_routers.begin_delete(resource_group.name, VIRTUAL_ROUTER_NAME)
        # result = result.result()

        # DeleteVirtualNetworkGateway[delete]
        times = 0
        for i in range(4):
            try:
                # TODO: not sure why something in progress makes this failed. so try 3 times.
                result = self.mgmt_client.virtual_network_gateways.begin_delete(
                    resource_group.name, VIRTUAL_NETWORK_GATEWAY_NAME
                )
                result = result.result()
            except HttpResponseError:
                if i >= 3:
                    raise HttpResponseError()
                else:
                    time.sleep(120)

        # DeleteLocalNetworkGateway[delete]
        result = self.mgmt_client.local_network_gateways.begin_delete(resource_group.name, LOCAL_NETWORK_GATEWAY_NAME)
        result = result.result()

        self.delete_network_interface(RESOURCE_GROUP, NETWORK_INTERFACE_NAME)

        # Delete subnet[delete]
        result = self.mgmt_client.subnets.begin_delete(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        result = result.result()

        # TODO: NOT ALLOW
        # Delete Virtual Network Tap resource[delete]
        # result = self.mgmt_client.virtual_network_taps.begin_delete(resource_group.name, VIRTUAL_NETWORK_TAP_NAME)
        # result = result.result()

        # Delete virtual network[delete]
        result = self.mgmt_client.virtual_networks.begin_delete(resource_group.name, VIRTUAL_NETWORK_NAME)
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

# covered ops:
#   virtual_networks: 8/8
#   subnets: 4/6  TODO: SubscriptionNotRegisteredForFeature in Prepare/Unprepare Network Policies

import unittest
import time
import pytest

import azure.mgmt.network.aio
from azure.core.exceptions import HttpResponseError
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

from _aio_testcase import AzureMgmtRecordedAsyncTestCase

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedAsyncTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_aio_client(azure.mgmt.network.aio.NetworkManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SERVICE_NAME = "myapimrndxyz"
        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name

        VIRTUAL_NETWORK_NAME = "virtualnetworkname"
        SUBNET_NAME = "subnetname"

        # Create virtual network[put]
        BODY = {"address_space": {"address_prefixes": ["10.0.0.0/16"]}, "location": "eastus"}
        result = self.event_loop.run_until_complete(
            self.mgmt_client.virtual_networks.begin_create_or_update(resource_group.name, VIRTUAL_NETWORK_NAME, BODY)
        )
        result = self.event_loop.run_until_complete(result.result())

        # Create subnet[put]
        BODY = {"address_prefix": "10.0.0.0/24"}
        result = self.event_loop.run_until_complete(
            self.mgmt_client.subnets.begin_create_or_update(
                resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME, BODY
            )
        )
        subnet = self.event_loop.run_until_complete(result.result())

        # Check IP address availability[get]
        IP_ADDRESS = "10.0.0.4"
        result = self.event_loop.run_until_complete(
            self.mgmt_client.virtual_networks.check_ip_address_availability(
                resource_group.name, VIRTUAL_NETWORK_NAME, ip_address=IP_ADDRESS
            )
        )

        # Get subnet[get]
        result = self.event_loop.run_until_complete(
            self.mgmt_client.subnets.get(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        )

        # List subnets[get]
        result = self.to_list(self.mgmt_client.subnets.list(resource_group.name, VIRTUAL_NETWORK_NAME))

        # VnetGetUsage[get]
        result = self.to_list(self.mgmt_client.virtual_networks.list_usage(resource_group.name, VIRTUAL_NETWORK_NAME))

        # Get virtual network[get]
        result = self.event_loop.run_until_complete(
            self.mgmt_client.virtual_networks.get(resource_group.name, VIRTUAL_NETWORK_NAME)
        )

        # List virtual networks in resource group[get]
        result = self.to_list(self.mgmt_client.virtual_networks.list(resource_group.name))

        # List all virtual networks[get]
        result = self.to_list(self.mgmt_client.virtual_networks.list_all())

        # Update virtual network tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.event_loop.run_until_complete(
            self.mgmt_client.virtual_networks.update_tags(resource_group.name, VIRTUAL_NETWORK_NAME, BODY)
        )

        # Delete subnet[delete]
        result = self.event_loop.run_until_complete(
            self.mgmt_client.subnets.begin_delete(resource_group.name, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        )
        result = self.event_loop.run_until_complete(result.result())

        # Delete virtual network[delete]
        result = self.event_loop.run_until_complete(
            self.mgmt_client.virtual_networks.begin_delete(resource_group.name, VIRTUAL_NETWORK_NAME)
        )
        result = self.event_loop.run_until_complete(result.result())


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 7
# Methods Covered : 7
# Examples Total  : 16
# Examples Tested : 16
# Coverage %      : 100
# ----------------------

#  azure_firewalls: 6/6
#  azure_firewall_fqdn_tags: 1/1

import unittest
import pytest

import azure.mgmt.network
from azure.core.exceptions import ResourceExistsError
from devtools_testutils import (
    AzureMgmtRecordedTestCase,
    ResourceGroupPreparer,
    RandomNameResourceGroupPreparer,
    recorded_by_proxy,
)

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    def create_firewall_policy(self, location, group_name, firewall_policy_name):
        BODY = {"tags": {"key1": "value1"}, "location": location, "threat_intel_mode": "Alert"}
        result = self.mgmt_client.firewall_policies.begin_create_or_update(
            resource_group_name=group_name, firewall_policy_name=firewall_policy_name, parameters=BODY
        )
        return result.result()

    def create_virtual_hub(self, location, group_name, virtual_wan_name, virtual_hub_name):

        # VirtualWANCreate[put]
        BODY = {"location": "West US", "tags": {"key1": "value1"}, "disable_vpn_encryption": False, "type": "Basic"}
        result = self.mgmt_client.virtual_wans.begin_create_or_update(group_name, virtual_wan_name, BODY)
        wan = result.result()

        BODY = {
            "location": "West US",
            "tags": {"key1": "value1"},
            "virtual_wan": {
                # "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualWans/" + VIRTUAL_WAN_NAME + ""
                "id": wan.id
            },
            "address_prefix": "10.168.0.0/24",
            "sku": "Basic",
        }
        result = self.mgmt_client.virtual_hubs.begin_create_or_update(group_name, virtual_hub_name, BODY)
        return result.result()

    @ResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        VIRTUAL_WAN_NAME = "virtualwan"
        VIRTUAL_HUB_NAME = "virtualhub"
        FIREWALL_POLICY_NAME = "firewallpolicy"

        AZURE_FIREWALL_NAME = "azurefirewall"

        self.create_virtual_hub(AZURE_LOCATION, RESOURCE_GROUP, VIRTUAL_WAN_NAME, VIRTUAL_HUB_NAME)
        self.create_firewall_policy(AZURE_LOCATION, RESOURCE_GROUP, FIREWALL_POLICY_NAME)

        # # Create Azure Firewall With management subnet[put]
        # BODY = {
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "location": "West US",
        #   "zones": [],
        #   "properties": {
        #     "sku": {
        #       "name": "AZFW_VNet",
        #       "tier": "Standard"
        #     },
        #     "threat_intel_mode": "Alert",
        #     "ip_configurations": [
        #       {
        #         "name": "azureFirewallIpConfiguration",
        #         "properties": {
        #           "subnet": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #           },
        #           "public_ip_address": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #           }
        #         }
        #       }
        #     ],
        #     "management_ip_configuration": {
        #       "name": "azureFirewallMgmtIpConfiguration",
        #       "properties": {
        #         "subnet": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #         },
        #         "public_ip_address": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #         }
        #       }
        #     },
        #     "application_rule_collections": [
        #       {
        #         "name": "apprulecoll",
        #         "properties": {
        #           "priority": "110",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "rule1",
        #               "description": "Deny inbound rule",
        #               "protocols": [
        #                 {
        #                   "protocol_type": "Https",
        #                   "port": "443"
        #                 }
        #               ],
        #               "target_fqdns": [
        #                 "www.test.com"
        #               ],
        #               "source_addresses": [
        #                 "216.58.216.164",
        #                 "10.0.0.0/24"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "nat_rule_collections": [
        #       {
        #         "name": "natrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Dnat"
        #           },
        #           "rules": [
        #             {
        #               "name": "DNAT-HTTPS-traffic",
        #               "description": "D-NAT all outbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "443"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_address": "1.2.3.5",
        #               "translated_port": "8443"
        #             },
        #             {
        #               "name": "DNAT-HTTP-traffic-With-FQDN",
        #               "description": "D-NAT all inbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "80"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_fqdn": "internalhttpserver",
        #               "translated_port": "880"
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "network_rule_collections": [
        #       {
        #         "name": "netrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "L4-traffic",
        #               "description": "Block traffic based on source IPs and ports",
        #               "source_addresses": [
        #                 "192.168.1.1-192.168.1.12",
        #                 "10.1.4.12-10.1.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_addresses": [
        #                 "*"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             },
        #             {
        #               "name": "L4-traffic-with-FQDN",
        #               "description": "Block traffic based on source IPs and ports to amazon",
        #               "source_addresses": [
        #                 "10.2.4.12-10.2.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_fqdns": [
        #                 "www.amazon.com"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ]
        #   }
        # }
        # result = self.mgmt_client.azure_firewalls.create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        # result = result.result()

        # # Create Azure Firewall With IpGroups[put]
        # BODY = {
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "location": "West US",
        #   "zones": [],
        #   "properties": {
        #     "sku": {
        #       "name": "AZFW_VNet",
        #       "tier": "Standard"
        #     },
        #     "threat_intel_mode": "Alert",
        #     "ip_configurations": [
        #       {
        #         "name": "azureFirewallIpConfiguration",
        #         "properties": {
        #           "subnet": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #           },
        #           "public_ip_address": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #           }
        #         }
        #       }
        #     ],
        #     "application_rule_collections": [
        #       {
        #         "name": "apprulecoll",
        #         "properties": {
        #           "priority": "110",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "rule1",
        #               "description": "Deny inbound rule",
        #               "protocols": [
        #                 {
        #                   "protocol_type": "Https",
        #                   "port": "443"
        #                 }
        #               ],
        #               "target_fqdns": [
        #                 "www.test.com"
        #               ],
        #               "source_addresses": [
        #                 "216.58.216.164",
        #                 "10.0.0.0/24"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "nat_rule_collections": [
        #       {
        #         "name": "natrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Dnat"
        #           },
        #           "rules": [
        #             {
        #               "name": "DNAT-HTTPS-traffic",
        #               "description": "D-NAT all outbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "443"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_address": "1.2.3.5",
        #               "translated_port": "8443"
        #             },
        #             {
        #               "name": "DNAT-HTTP-traffic-With-FQDN",
        #               "description": "D-NAT all inbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "80"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_fqdn": "internalhttpserver",
        #               "translated_port": "880"
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "network_rule_collections": [
        #       {
        #         "name": "netrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "L4-traffic",
        #               "description": "Block traffic based on source IPs and ports",
        #               "source_addresses": [
        #                 "192.168.1.1-192.168.1.12",
        #                 "10.1.4.12-10.1.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_addresses": [
        #                 "*"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             },
        #             {
        #               "name": "L4-traffic-with-FQDN",
        #               "description": "Block traffic based on source IPs and ports to amazon",
        #               "source_addresses": [
        #                 "10.2.4.12-10.2.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_fqdns": [
        #                 "www.amazon.com"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ]
        #   }
        # }
        # result = self.mgmt_client.azure_firewalls.create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        # result = result.result()

        # # Create Azure Firewall With Additional Properties[put]
        # BODY = {
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "location": "West US",
        #   "zones": [],
        #   "properties": {
        #     "sku": {
        #       "name": "AZFW_VNet",
        #       "tier": "Standard"
        #     },
        #     "threat_intel_mode": "Alert",
        #     "ip_configurations": [
        #       {
        #         "name": "azureFirewallIpConfiguration",
        #         "properties": {
        #           "subnet": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #           },
        #           "public_ip_address": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #           }
        #         }
        #       }
        #     ],
        #     "application_rule_collections": [
        #       {
        #         "name": "apprulecoll",
        #         "properties": {
        #           "priority": "110",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "rule1",
        #               "description": "Deny inbound rule",
        #               "protocols": [
        #                 {
        #                   "protocol_type": "Https",
        #                   "port": "443"
        #                 }
        #               ],
        #               "target_fqdns": [
        #                 "www.test.com"
        #               ],
        #               "source_addresses": [
        #                 "216.58.216.164",
        #                 "10.0.0.0/24"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "nat_rule_collections": [
        #       {
        #         "name": "natrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Dnat"
        #           },
        #           "rules": [
        #             {
        #               "name": "DNAT-HTTPS-traffic",
        #               "description": "D-NAT all outbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "443"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_address": "1.2.3.5",
        #               "translated_port": "8443"
        #             },
        #             {
        #               "name": "DNAT-HTTP-traffic-With-FQDN",
        #               "description": "D-NAT all inbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "80"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_fqdn": "internalhttpserver",
        #               "translated_port": "880"
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "network_rule_collections": [
        #       {
        #         "name": "netrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "L4-traffic",
        #               "description": "Block traffic based on source IPs and ports",
        #               "source_addresses": [
        #                 "192.168.1.1-192.168.1.12",
        #                 "10.1.4.12-10.1.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_addresses": [
        #                 "*"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             },
        #             {
        #               "name": "L4-traffic-with-FQDN",
        #               "description": "Block traffic based on source IPs and ports to amazon",
        #               "source_addresses": [
        #                 "10.2.4.12-10.2.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_fqdns": [
        #                 "www.amazon.com"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "ip_groups": [],
        #     "additional_properties": {
        #       "key1": "value1",
        #       "key2": "value2"
        #     }
        #   }
        # }
        # result = self.mgmt_client.azure_firewalls.create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        # result = result.result()

        # Create Azure Firewall in virtual Hub[put]
        BODY = {
            "tags": {"key1": "value1"},
            "location": "West US",
            "zones": [],
            "sku": {"name": "AZFW_Hub", "tier": "Standard"},
            # "threat_intel_mode": "Off",
            "virtual_hub": {
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/virtualHubs/"
                + VIRTUAL_HUB_NAME
                + ""
            },
            "hub_ip_addresses": {"public_i_ps": {"addresses": [], "count": 1}},
            "firewall_policy": {
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/firewallPolicies/"
                + FIREWALL_POLICY_NAME
                + ""
            },
        }
        result = self.mgmt_client.azure_firewalls.begin_create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        result = result.result()

        # # Create Azure Firewall[put]
        # BODY = {
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "location": "West US",
        #   "zones": [],
        #   "properties": {
        #     "sku": {
        #       "name": "AZFW_VNet",
        #       "tier": "Standard"
        #     },
        #     "threat_intel_mode": "Alert",
        #     "ip_configurations": [
        #       {
        #         "name": "azureFirewallIpConfiguration",
        #         "properties": {
        #           "subnet": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #           },
        #           "public_ip_address": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #           }
        #         }
        #       }
        #     ],
        #     "application_rule_collections": [
        #       {
        #         "name": "apprulecoll",
        #         "properties": {
        #           "priority": "110",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "rule1",
        #               "description": "Deny inbound rule",
        #               "protocols": [
        #                 {
        #                   "protocol_type": "Https",
        #                   "port": "443"
        #                 }
        #               ],
        #               "target_fqdns": [
        #                 "www.test.com"
        #               ],
        #               "source_addresses": [
        #                 "216.58.216.164",
        #                 "10.0.0.0/24"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "nat_rule_collections": [
        #       {
        #         "name": "natrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Dnat"
        #           },
        #           "rules": [
        #             {
        #               "name": "DNAT-HTTPS-traffic",
        #               "description": "D-NAT all outbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "443"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_address": "1.2.3.5",
        #               "translated_port": "8443"
        #             },
        #             {
        #               "name": "DNAT-HTTP-traffic-With-FQDN",
        #               "description": "D-NAT all inbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "80"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_fqdn": "internalhttpserver",
        #               "translated_port": "880"
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "network_rule_collections": [
        #       {
        #         "name": "netrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "L4-traffic",
        #               "description": "Block traffic based on source IPs and ports",
        #               "source_addresses": [
        #                 "192.168.1.1-192.168.1.12",
        #                 "10.1.4.12-10.1.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_addresses": [
        #                 "*"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             },
        #             {
        #               "name": "L4-traffic-with-FQDN",
        #               "description": "Block traffic based on source IPs and ports to amazon",
        #               "source_addresses": [
        #                 "10.2.4.12-10.2.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_fqdns": [
        #                 "www.amazon.com"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ]
        #   }
        # }
        # result = self.mgmt_client.azure_firewalls.create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        # result = result.result()

        # # Create Azure Firewall With Zones[put]
        # BODY = {
        #   "location": "West US 2",
        #   "tags": {
        #     "key1": "value1"
        #   },
        #   "zones": [
        #     "1",
        #     "2",
        #     "3"
        #   ],
        #   "properties": {
        #     "threat_intel_mode": "Alert",
        #     "sku": {
        #       "name": "AZFW_VNet",
        #       "tier": "Standard"
        #     },
        #     "ip_configurations": [
        #       {
        #         "name": "azureFirewallIpConfiguration",
        #         "properties": {
        #           "subnet": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME + ""
        #           },
        #           "public_ip_address": {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddresses/" + PUBLIC_IP_ADDRESS_NAME + ""
        #           }
        #         }
        #       }
        #     ],
        #     "application_rule_collections": [
        #       {
        #         "name": "apprulecoll",
        #         "properties": {
        #           "priority": "110",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "rule1",
        #               "description": "Deny inbound rule",
        #               "protocols": [
        #                 {
        #                   "protocol_type": "Https",
        #                   "port": "443"
        #                 }
        #               ],
        #               "target_fqdns": [
        #                 "www.test.com"
        #               ],
        #               "source_addresses": [
        #                 "216.58.216.164",
        #                 "10.0.0.0/24"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "nat_rule_collections": [
        #       {
        #         "name": "natrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Dnat"
        #           },
        #           "rules": [
        #             {
        #               "name": "DNAT-HTTPS-traffic",
        #               "description": "D-NAT all outbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "443"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_address": "1.2.3.5",
        #               "translated_port": "8443"
        #             },
        #             {
        #               "name": "DNAT-HTTP-traffic-With-FQDN",
        #               "description": "D-NAT all inbound web traffic for inspection",
        #               "source_addresses": [
        #                 "*"
        #               ],
        #               "destination_addresses": [
        #                 "1.2.3.4"
        #               ],
        #               "destination_ports": [
        #                 "80"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ],
        #               "translated_fqdn": "internalhttpserver",
        #               "translated_port": "880"
        #             }
        #           ]
        #         }
        #       }
        #     ],
        #     "network_rule_collections": [
        #       {
        #         "name": "netrulecoll",
        #         "properties": {
        #           "priority": "112",
        #           "action": {
        #             "type": "Deny"
        #           },
        #           "rules": [
        #             {
        #               "name": "L4-traffic",
        #               "description": "Block traffic based on source IPs and ports",
        #               "source_addresses": [
        #                 "192.168.1.1-192.168.1.12",
        #                 "10.1.4.12-10.1.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_addresses": [
        #                 "*"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             },
        #             {
        #               "name": "L4-traffic-with-FQDN",
        #               "description": "Block traffic based on source IPs and ports to amazon",
        #               "source_addresses": [
        #                 "10.2.4.12-10.2.4.255"
        #               ],
        #               "destination_ports": [
        #                 "443-444",
        #                 "8443"
        #               ],
        #               "destination_fqdns": [
        #                 "www.amazon.com"
        #               ],
        #               "protocols": [
        #                 "TCP"
        #               ]
        #             }
        #           ]
        #         }
        #       }
        #     ]
        #   }
        # }
        # result = self.mgmt_client.azure_firewalls.create_or_update(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        # result = result.result()

        # # Get Azure Firewall With management subnet[get]
        # result = self.mgmt_client.azure_firewalls.get(resource_group.name, AZURE_FIREWALL_NAME)

        # # Get Azure Firewall With Additional Properties[get]
        # result = self.mgmt_client.azure_firewalls.get(resource_group.name, AZURE_FIREWALL_NAME)

        # # Get Azure Firewall With IpGroups[get]
        # result = self.mgmt_client.azure_firewalls.get(resource_group.name, AZURE_FIREWALL_NAME)

        # Get Azure Firewall[get]
        result = self.mgmt_client.azure_firewalls.get(resource_group.name, AZURE_FIREWALL_NAME)

        # # Get Azure Firewall With Zones[get]
        # result = self.mgmt_client.azure_firewalls.get(resource_group.name, AZURE_FIREWALL_NAME)

        # List all Azure Firewalls for a given resource group[get]
        result = self.mgmt_client.azure_firewalls.list(resource_group.name)

        # List all Azure Firewall FQDN Tags for a given subscription[get]
        result = self.mgmt_client.azure_firewall_fqdn_tags.list_all()

        # List all Azure Firewalls for a given subscription[get]
        result = self.mgmt_client.azure_firewalls.list_all()

        # Update Azure Firewall Tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.azure_firewalls.begin_update_tags(resource_group.name, AZURE_FIREWALL_NAME, BODY)
        result = result.result()

        # Delete Azure Firewall[delete]
        try:
            result = self.mgmt_client.azure_firewalls.begin_delete(resource_group.name, AZURE_FIREWALL_NAME)
            result = result.result()
        except ResourceExistsError as e:
            if not str(e).startswith("(AnotherOperationInProgress)"):
                raise e


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 5
# Methods Covered : 5
# Examples Total  : 5
# Examples Tested : 5
# Coverage %      : 100
# ----------------------

#  web_application_firewall_policies: /5

import unittest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
import pytest

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        POLICY_NAME = "myPolicy"

        # /WebApplicationFirewallPolicies/put/Creates or updates a WAF policy within a resource group[put]
        BODY = {
            "location": "WestUs",
            "managed_rules": {"managed_rule_sets": [{"rule_set_type": "OWASP", "rule_set_version": "3.0"}]},
            "custom_rules": [
                # {
                #   "name": "Rule1",
                #   "priority": "1",
                #   "rule_type": "MatchRule",
                #   "action": "Block",
                #   "match_conditions": [
                #     {
                #       "match_variables": [
                #         {
                #           "variable_name": "RemoteAddr"
                #         }
                #       ],
                #       "operator": "IPMatch",
                #       "match_values": [
                #         "192.168.1.0/24",
                #         "10.0.0.0/24"
                #       ]
                #     }
                #   ]
                # },
                # {
                #   "name": "Rule2",
                #   "priority": "2",
                #   "rule_type": "MatchRule",
                #   "match_conditions": [
                #     {
                #       "match_variables": [
                #         {
                #           "variable_name": "RemoteAddr"
                #         }
                #       ],
                #       "operator": "IPMatch",
                #       "match_values": [
                #         "192.168.1.0/24"
                #       ]
                #     },
                #     {
                #       "match_variables": [
                #         {
                #           "variable_name": "RequestHeaders",
                #           "selector": "UserAgent"
                #         }
                #       ],
                #       "operator": "Contains",
                #       "match_values": [
                #         "Windows"
                #       ]
                #     }
                #   ],
                #   "action": "Block"
                # }
            ],
        }
        result = self.mgmt_client.web_application_firewall_policies.create_or_update(
            resource_group_name=RESOURCE_GROUP, policy_name=POLICY_NAME, parameters=BODY
        )

        # /WebApplicationFirewallPolicies/get/Gets a WAF policy within a resource group[get]
        result = self.mgmt_client.web_application_firewall_policies.get(
            resource_group_name=RESOURCE_GROUP, policy_name=POLICY_NAME
        )

        # /WebApplicationFirewallPolicies/get/Lists all WAF policies in a resource group[get]
        result = self.mgmt_client.web_application_firewall_policies.list(resource_group_name=RESOURCE_GROUP)

        # /WebApplicationFirewallPolicies/get/Lists all WAF policies in a subscription[get]
        result = self.mgmt_client.web_application_firewall_policies.list_all()

        # /WebApplicationFirewallPolicies/delete/Deletes a WAF policy within a resource group[delete]
        result = self.mgmt_client.web_application_firewall_policies.begin_delete(
            resource_group_name=RESOURCE_GROUP, policy_name=POLICY_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()
